package dk.deranged.android.refleq;

import java.util.Observable;

import android.app.Activity;
import android.view.View;

public class RefleqButton extends Observable implements Comparable<RefleqButton> {
	private View button;
	private Activity parent;
	private long timestamp = Long.MAX_VALUE;

	public RefleqButton(Activity parent, View button) {
		this.parent = parent;
		this.button = button;
		button.setAlpha(0.2f);
		button.setClickable(true);
	}
	
	public boolean isActive() {
		return button.getAlpha() == 1f;
	}
	
	public void activate(long millis) {
		timestamp = (System.nanoTime()/1000) + millis;
		parent.runOnUiThread(new AlphaSetter(button,1f));
	}
	
	public void deactivate() {
		timestamp = Long.MAX_VALUE;
		parent.runOnUiThread(new AlphaSetter(button,0.2f));
	}
	
	public long deactivateTimestamp() {
		return timestamp;
	}
	
	public void setOnClickListener(View.OnClickListener l) {
		button.setOnClickListener(l);
	}
	
	public View view() {
		return button;
	}
	
	public int compareTo(RefleqButton b) {
		return (int) Math.signum(deactivateTimestamp() - b.deactivateTimestamp());
	}
	
	private class AlphaSetter implements Runnable {
		private View item;
		private float alpha;
		
		public AlphaSetter(View item, float alpha) {
			this.item = item;
			this.alpha = alpha;
		}
		
		public void run() {
			item.setAlpha(alpha);
		}
	}
	
}
